package cz.moneta.test.dsl.ufo.banka.pages.income;

import cz.moneta.test.harness.support.web.Key;
import cz.moneta.test.harness.support.web.KeyPress;
import cz.moneta.test.harness.support.web.TypeInto;

public interface Extend_FinancialIncomePageForPo extends FIN002_S002_FinancialIncomePage {
    //Aktiva
    String SUBSCRIBED_CAPITAL_INPUT = "FIN002_S002_E028";
    String CURRENT_ASSETS_INPUT = "FIN002_S002_E029";
    String LONGTERM_PROPERTY_INPUT = "FIN002_S002_E030";
    String ASSET_ACCRUALS_INPUT = "FIN002_S002_E031";

    //Pasiva
    String RESERVES_INPUT = "FIN002_S002_E032";
    String OWN_CAPITAL_INPUT = "FIN002_S002_E033";
    String LONGTERM_OBLIGATIONS_INPUT = "FIN002_S002_E034";
    String SHORTTERM_OBLIGATIONS_INPUT = "FIN002_S002_E035";
    String ACCRUED_LIABILITIES_CIII_INPUT = "FIN002_S002_E036";
    String ACCRUED_LIABILITIES_INPUT = "FIN002_S002_E037";

    //Vykaz zisku a ztraty
    String PRODUCTS_SERVICES_REVENUE_INPUT = "FIN002_S002_E040";
    String GOODS_REVENUE_INPUT = "FIN002_S002_E041";
    String PERFORMANCE_CONSUMPTION_INPUT = "FIN002_S002_E042";
    String STORAGE_CHANGE_INPUT = "FIN002_S002_E043";
    String ACTIVATION_INPUT = "FIN002_S002_E044";
    String PERSONAL_COSTS_INPUT = "FIN002_S002_E045";
    String OPERATING_AREA_EDITING_VALUES_INPUT = "FIN002_S002_E046";
    String OTHER_OPERATING_INCOME_INPUT = "FIN002_S002_E047";
    String OPERATING_PROFIT_INPUT = "FIN002_S002_E048";
    String ECONOMY_RESULT_AFTER_TAX_PAYMENT_INPUT = "FIN002_S002_E049";
    String SHARES_TRANSFER_TO_PARTNERS_INPUT = "FIN002_S002_E050";
    String ACCOUNTING_PERIOD_ECONOMY_RESULT_INPUT = "FIN002_S002_E051";
    String OTHER_OPERATING_COSTS_INPUT = "FIN002_S002_E053";

    String UNDER_OR_OVERPAYMENT_INPUT = "FIN002_S002_E052";

    @TypeInto(UNDER_OR_OVERPAYMENT_INPUT)
    Extend_FinancialIncomePageForPo fillUnderOrOverpayment(String underOrOverpayment);

    @TypeInto(SUBSCRIBED_CAPITAL_INPUT)
    Extend_FinancialIncomePageForPo fillSubscribedCapital(String subscribedCapital);

    @TypeInto(CURRENT_ASSETS_INPUT)
    Extend_FinancialIncomePageForPo fillCurrentAssets(String currentAssets);

    @TypeInto(LONGTERM_PROPERTY_INPUT)
    Extend_FinancialIncomePageForPo fillLongtermProperty(String longtermProperty);

    @TypeInto(ASSET_ACCRUALS_INPUT)
    Extend_FinancialIncomePageForPo fillAssetAccruals(String assetAccruals);

    @TypeInto(RESERVES_INPUT)
    Extend_FinancialIncomePageForPo fillReserves(String reserves);

    @TypeInto(OWN_CAPITAL_INPUT)
    Extend_FinancialIncomePageForPo fillOwnCapital(String ownCapital);

    @TypeInto(LONGTERM_OBLIGATIONS_INPUT)
    Extend_FinancialIncomePageForPo fillLongtermObligations(String longtermObligations);

    @TypeInto(SHORTTERM_OBLIGATIONS_INPUT)
    Extend_FinancialIncomePageForPo fillShorttermObligations(String shorttermObligations);

    @TypeInto(ACCRUED_LIABILITIES_CIII_INPUT)
    Extend_FinancialIncomePageForPo fillAccruedLiabilitiesCiii(String accruedLiabilitiesCiii);

    @TypeInto(ACCRUED_LIABILITIES_INPUT)
    Extend_FinancialIncomePageForPo fillAccruedLiabilities(String accruedLiabilities);

    @TypeInto(PRODUCTS_SERVICES_REVENUE_INPUT)
    Extend_FinancialIncomePageForPo fillProductsServicesRevenue(String productServicesRevenue);

    @TypeInto(GOODS_REVENUE_INPUT)
    Extend_FinancialIncomePageForPo fillGoodsRevenue(String goodsRevenue);

    @TypeInto(PERFORMANCE_CONSUMPTION_INPUT)
    Extend_FinancialIncomePageForPo fillPerformanceConsumption(String performanceConsumption);

    @TypeInto(STORAGE_CHANGE_INPUT)
    Extend_FinancialIncomePageForPo fillStorageChange(String storageChange);

    @TypeInto(ACTIVATION_INPUT)
    Extend_FinancialIncomePageForPo fillActivationInput(String activationInput);

    @TypeInto(PERSONAL_COSTS_INPUT)
    Extend_FinancialIncomePageForPo fillPersonalCosts(String personalCosts);

    @TypeInto(OPERATING_AREA_EDITING_VALUES_INPUT)
    Extend_FinancialIncomePageForPo fillOperatingAreaEditingValues(String operatingAreaEditingValues);

    @TypeInto(OTHER_OPERATING_INCOME_INPUT)
    Extend_FinancialIncomePageForPo fillOtherOperatingIncome(String otherOperatingIncome);

    @TypeInto(OPERATING_PROFIT_INPUT)
    Extend_FinancialIncomePageForPo fillOperatingProfit(String operatingProfit);

    @TypeInto(ECONOMY_RESULT_AFTER_TAX_PAYMENT_INPUT)
    Extend_FinancialIncomePageForPo fillEconomyResultAfterTax(String economyResultAfterTax);

    @TypeInto(SHARES_TRANSFER_TO_PARTNERS_INPUT)
    Extend_FinancialIncomePageForPo fillSharesTransferToPartners(String shareTransferToPartners);

    @TypeInto(ACCOUNTING_PERIOD_ECONOMY_RESULT_INPUT)
    @KeyPress(Key.TAB)
    Extend_FinancialIncomePageForPo fillAccountingPeriodEconomyResult(String accountingPeriodEconomyResult);

    @TypeInto(OTHER_OPERATING_COSTS_INPUT)
    Extend_FinancialIncomePageForPo fillOtherOperatingCosts(String otherEconomyCosts);
}
